Index: components/test/android/browsertests_apk/src/org/chromium/components_browsertests_apk/ComponentsBrowserTestsActivity.java |
diff --git a/content/shell/android/browsertests_apk/src/org/chromium/content_browsertests_apk/ContentBrowserTestsActivity.java b/components/test/android/browsertests_apk/src/org/chromium/components_browsertests_apk/ComponentsBrowserTestsActivity.java |
similarity index 85% |
copy from content/shell/android/browsertests_apk/src/org/chromium/content_browsertests_apk/ContentBrowserTestsActivity.java |
copy to components/test/android/browsertests_apk/src/org/chromium/components_browsertests_apk/ComponentsBrowserTestsActivity.java |
index bc95f1cbe83fe9223dfe025aee6b8e8747b7d581..bbf2461f158b360f734173c282031b369ebac98f 100644 |
--- a/content/shell/android/browsertests_apk/src/org/chromium/content_browsertests_apk/ContentBrowserTestsActivity.java |
+++ b/components/test/android/browsertests_apk/src/org/chromium/components_browsertests_apk/ComponentsBrowserTestsActivity.java |
@@ -1,8 +1,8 @@ |
-// Copyright 2012 The Chromium Authors. All rights reserved. |
+// Copyright 2015 The Chromium Authors. All rights reserved. |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-package org.chromium.content_browsertests_apk; |
+package org.chromium.components_browsertests_apk; |
import android.app.Activity; |
import android.content.Context; |
@@ -23,11 +23,11 @@ import org.chromium.ui.base.ActivityWindowAndroid; |
import org.chromium.ui.base.WindowAndroid; |
/** |
* Android activity for running content browser tests |
*/ |
-@JNINamespace("content") |
-public class ContentBrowserTestsActivity extends Activity { |
- private static final String TAG = "ChromeBrowserTestsActivity"; |
+@JNINamespace("components") |
+public class ComponentsBrowserTestsActivity extends Activity { |
+ private static final String TAG = "ComponentsBrowserTestsActivity"; |
private ShellManager mShellManager; |
private WindowAndroid mWindowAndroid; |
@@ -40,7 +40,7 @@ public class ContentBrowserTestsActivity extends Activity { |
try { |
LibraryLoader.get(LibraryProcessType.PROCESS_BROWSER).ensureInitialized(); |
} catch (ProcessInitException e) { |
- Log.i(TAG, "Cannot load content_browsertests:" + e); |
+ Log.i(TAG, "Cannot load components_browsertests:" + e); |
System.exit(-1); |
} |
BrowserStartupController.get(getApplicationContext(), LibraryProcessType.PROCESS_BROWSER) |
@@ -23,11 +23,11 @@ import org.chromium.ui.base.ActivityWindowAndroid; |
import org.chromium.ui.base.WindowAndroid; |
/** |
- * Android activity for running content browser tests |
+ * Android activity for running components browser tests |
*/ |